@@ -16,6 +16,8 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
+#include "view.h"
+
 #include <QFileDialog>
 #include <QQmlEngine>
 #include <QQuickItem>
@@ -27,17 +29,16 @@
 #include <KLocalizedString>
 #include <KDesktopFile>
 
-#include <Plasma/Package>
-#include <Plasma/PluginLoader>
+#include <KPackage/Package>
+#include <KPackage/PackageLoader>
 
-#include "view.h"
 
 class ViewerCorona : public Plasma::Corona
 {
 public:
     ViewerCorona()
         : Plasma::Corona(),
-          m_view(0)
+          m_view(nullptr)
     {}
 
     void setView(View *view)
@@ -45,7 +46,7 @@ public:
         m_view = view;
     }
 
-    QRect screenGeometry(int id) const
+    QRect screenGeometry(int id) const override
     {
         Q_UNUSED(id);
         if (m_view) {
@@ -65,7 +66,7 @@ View::View(ViewerCorona *cor, bool konsoleVisible, QWindow *parent)
     cor->setView(this);
     m_konsoleVisible = konsoleVisible;
     engine()->rootContext()->setContextProperty("desktop", this);
-    setSource(QUrl::fromLocalFile(cor->package().filePath("views", "Desktop.qml")));
+    setSource(QUrl::fromLocalFile(cor->kPackage().filePath("views", "Desktop.qml")));
 }
 
 View::~View()
@@ -98,15 +99,23 @@ void View::addApplet(const QString &applet)
         return;
     }
 
-    Plasma::Applet *a = 0;
+    Plasma::Applet *a = nullptr;
     if (metadataPath.isEmpty()) {
         a = containment()->createApplet(applet);
     } else {
         a = Plasma::Applet::loadPlasmoid(metadataPath);
+
+        // Load translations from KPackage files if bundled
+        const QString localePath = a->kPackage().filePath("translations");
+        if (!localePath.isEmpty()) {
+            const QString localeDomain = QByteArray("plasma_applet_") + a->pluginMetaData().pluginId();
+            KLocalizedString::addDomainLocaleDir(localeDomain.toLatin1(), localePath);
+        }
+
         containment()->addApplet(a);
     }
 
-    if (!a->pluginInfo().isValid()) {
+    if (!a->pluginMetaData().isValid()) {
         // xgettext:no-c-format
         qCritical() << i18n("Applet %1 does not exist.", applet);
         return;
@@ -123,7 +132,7 @@ void View::addContainment(const QString &cont)
 
     Plasma::Containment *c = corona()->createContainment(actualCont);
 
-    if (!c->pluginInfo().isValid()) {
+    if (!c->pluginMetaData().isValid()) {
         // xgettext:no-c-format
         qCritical() << i18n("Containment %1 does not exist.", actualCont);
         return;
@@ -132,8 +141,8 @@ void View::addContainment(const QString &cont)
     setContainment(c);
 
     connect(containment(), &Plasma::Containment::appletRemoved, [=](Plasma::Applet *applet) {
-        if (applet && applet->pluginInfo().isValid()) {
-            addApplet(applet->pluginInfo().pluginName());
+        if (applet && applet->pluginMetaData().isValid()) {
+            addApplet(applet->pluginMetaData().pluginId());
         }
     });
 }
@@ -277,11 +286,11 @@ void View::changeLocation(int location)
 
 ViewerCorona *View::createCorona()
 {
-    Plasma::Package package = Plasma::PluginLoader::self()->loadPackage("Plasma/Shell");
+    KPackage::Package package = KPackage::PackageLoader::self()->loadPackage("Plasma/Shell");
     package.setPath("org.kde.plasma.plasmoidviewershell");
 
     ViewerCorona *cor = new ViewerCorona();
-    cor->setPackage(package);
+    cor->setKPackage(package);
 
     return cor;
 }
@@ -305,7 +314,7 @@ void View::takeScreenShot()
             return;
         }
 
-        QString dest = QFileDialog::getSaveFileName(0, i18nc("@title:window", "Save Screenshot"),
+        QString dest = QFileDialog::getSaveFileName(nullptr, i18nc("@title:window", "Save Screenshot"),
                                                     QDir::homePath(), QStringLiteral("Images (*.png)"));
 
         if (dest.isEmpty()) {
